<div class="control-group{% if field.errors %} error{% endif %}">
    <label
        class="control-label{% if field.field.required %} required{% endif %}"
        for="{{field.name}}"
    >
        {{ field.label }}
    </label>
    <div class="controls">
        {{ field }}
        {% if field.errors %}
        <span class="help-block">
            {% for e in field.errors %}{{ e }}{% endfor %}
        </span>
        {% else %}
        {% if field.help_text %}
        <span class="icon-question-sign help-tooltip"
            title="{{ field.help_text|escape }}" />
        {% endif %}
        {% endif %}
    </div>
</div>

