{% load bob %}
<form
    class="form {{ css_class }}"
    method="{{ method.upper }}"
    {% dependency_data form %}
{% if form.is_multipart %}
    enctype="multipart/form-data"
{% endif %}
    action="{{ action }}">
{% if method.upper == "POST" %}{% csrf_token %}{% endif %}
{% for f in form.hidden_fields %}{{ f }}{% endfor %}
{% for f in form.visible_fields %}
    {% field_wrapper f %}
{% endfor %}
<div class="form-actions">
    {% spaceless %}
    <button type="submit" class="btn btn-primary"><i
        {% if fugue_icons %}
        class="fugue-icon fugue-tick"
        {% else %}
        class="icon-ok icon-white"
        {% endif %}
        ></i>&nbsp;{{submit_label}}</button>
    {% endspaceless %}
</div>
</form>
